[slf4j-dev] svn commit: r555 - slf4j/trunk/src/java/org/slf4j/impl

ceki at slf4j.org ceki at slf4j.org
Wed Mar 8 20:06:26 CET 2006


Author: ceki
Date: Wed Mar  8 20:06:25 2006
New Revision: 555

Modified:
   slf4j/trunk/src/java/org/slf4j/impl/SimpleLogger.java
Log:
Per discussions on the slf4j user mailing list [1], changing the target 
of SimpleLogger to System.err instead of System.out.

[1] http://marc.theaimsgroup.com/?t=114063163800004&r=1&w=2 

Modified: slf4j/trunk/src/java/org/slf4j/impl/SimpleLogger.java
==============================================================================
--- slf4j/trunk/src/java/org/slf4j/impl/SimpleLogger.java	(original)
+++ slf4j/trunk/src/java/org/slf4j/impl/SimpleLogger.java	Wed Mar  8 20:06:25 2006
@@ -35,7 +35,7 @@
 
 /**
  * A simple (and direct) implementation that logs messages of level
  * INFO or higher on the console (<code>System.out<code>).
  *
  * <p>The output includes the relative time in milliseconds, thread
  * name, the level, logger name, and the message followed by the line
@@ -154,11 +154,11 @@
 
     buf.append(LINE_SEPARATOR);
 
-    System.out.print(buf.toString());
+    System.err.print(buf.toString());
     if (t != null) {
-      t.printStackTrace(System.out);
+      t.printStackTrace(System.err);
     }
-    System.out.flush();
+    System.err.flush();
   }
 
   /**
@@ -35,7 +35,7 @@
 /**
  * A simple (and direct) implementation that logs messages of level
- * INFO or higher on the console (<code>System.out<code>).
+ * INFO or higher on the console (<code>System.err<code>).
  *
  * <p>The output includes the relative time in milliseconds, thread



More information about the slf4j-dev mailing list